@@ -86,7 +86,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x54300
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x54800
 #  endif
 #endif
 
@@ -139,8 +139,21 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_67(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54600
+#  define KCOREADDONS_DEPRECATED_VERSION_5_70(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_70(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54800
+#  define KCOREADDONS_DEPRECATED_VERSION_5_72(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_72(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KCOREADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KCOREADDONS_EXPORT_H */
